@@ -52,7 +52,7 @@ pb_delete <- function(file = NULL,
     )
   })
 
-  try({memoise::forget(pb_info)})
+  .pb_cache_clear()
 
   if(getOption("piggyback.verbose", default = TRUE)) cli::cli_alert_info("Deleted {.val {file}} from {.val {tag}} release on {.val {repo}}")
 
